@@ -4,7 +4,7 @@ vuongtest<-function(model1,model2,selection="AIC"){
     m<-ll1-ll2
     t.stat<-sqrt(length(m))*mean(m)/sd(m)
     if (selection=="AIC"){
-	t.stat=t.stat -(model1$npar --model2$npar)
+	t.stat=t.stat -(model1$npar -model2$npar)
 	}
     if (selection=="BIC"){
 	n=length(ll1)
